#
# spec file for package pqiv
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pqiv
Version:        2.13.1
Release:        1.6
Summary:        Minimalist image viewer
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://github.com/phillipberndt/pqiv
Source:         https://github.com/phillipberndt/pqiv/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libspectre)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(poppler)
BuildRequires:  pkgconfig(poppler-glib)

%description
pqiv is a powerful GTK 3 based command-line image viewer with a minimal UI. It
is highly customizable, can be fully controlled from scripts, and has support
for various file formats including PDF, Postscript, video files and archives.
It is optimized to be quick and responsive.
It comes with support for animations, slideshows, transparency, VIM-like key
bindings, automated loading of new images as they appear, external image
filters, image preloading, and much more.
pqiv started as a Python rewrite of qiv avoiding imlib, but evolved into a much
more powerful tool. Today, pqiv stands for powerful quick image viewer.
Features:
 * Command line image viewer
 * Directory traversing to view whole directories
 * Watch files and directories for changes
 * Natural order sorting of the images
 * A status bar showing information on the current image
 * Transparency and animation support
 * Moving, zooming, rotation, flipping
 * Slideshows
 * Highly customizable and scriptable
 * Supports external image filters (e.g. `convert`)
 * Preloads the next image in the background
 * Fade between images
 * Optional PDF/eps/ps support (useful e.g. for scientific plots)
 * Optional video format support (e.g. for webm animations)

%package ffmpeg
Summary:        Backend ffmpeg/libav for %{name}
Group:          Productivity/Graphics/Viewers
Requires:       %{name} = %{version}

%description ffmpeg
Backend ffmpeg/libav for %{name}

%package gdkpixbuf
Summary:        Backend gdkpixbuf for %{name}
Group:          Productivity/Graphics/Viewers
Requires:       %{name} = %{version}

%description gdkpixbuf
Backend gdkpixbuf for %{name}

%package libarchive
Summary:        Backend libarchive for %{name}
Group:          Productivity/Graphics/Viewers
Requires:       %{name} = %{version}

%description libarchive
Backend libarchive/libarchive_cbx for %{name}

%package poppler
Summary:        Backend poppler for %{name}
Group:          Productivity/Graphics/Viewers
Requires:       %{name} = %{version}

%description poppler
Backend poppler for %{name}

%package spectre
Summary:        Backend spectre for %{name}
Group:          Productivity/Graphics/Viewers
Requires:       %{name} = %{version}

%description spectre
Backend spectre for %{name}

%package wand
Summary:        Backend wand for %{name}
Group:          Productivity/Graphics/Viewers
Requires:       %{name} = %{version}

%description wand
Backend wand for %{name}

%package webp
Summary:        Backend webp for %{name}
Group:          Productivity/Graphics/Viewers
Requires:       %{name} = %{version}

%description webp
Backend webp for %{name}

%prep
%setup -q

%build
./configure \
  --libdir=%{_libdir} \
  --backends-build=shared \
  --backends=archive_cbx,gdkpixbuf,libav,poppler,spectre,wand,webp

%make_build

%install
%make_install

%files
%{_mandir}/man1/%{name}.1%{?ext_man}
%dir %{_libdir}/%{name}
%doc README.markdown
%license LICENSE
%{_datadir}/applications/pqiv.desktop
%{_bindir}/%{name}

%files ffmpeg
%{_libdir}/%{name}/%{name}-backend-libav.so

%files gdkpixbuf
%{_libdir}/%{name}/%{name}-backend-gdkpixbuf.so

%files libarchive
%{_libdir}/%{name}/%{name}-backend-archive.so
%{_libdir}/%{name}/%{name}-backend-archive_cbx.so

%files poppler
%{_libdir}/%{name}/%{name}-backend-poppler.so

%files spectre
%{_libdir}/%{name}/%{name}-backend-spectre.so

%files wand
%{_libdir}/%{name}/%{name}-backend-wand.so

%files webp
%{_libdir}/%{name}/%{name}-backend-webp.so

%changelog
* Wed Apr 24 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 2.13.1:
  * Fix fullscreen toggle bug by @wsldankers in #190
  * Use larger thumbnails from newer spec by @chrysn in #199
  * Use Pango to render infobox text. by @buzzingwires in #221
  * .desktop file: Run pqiv --browse by @chrysn in #204
  * thumbnails: Tolerate absence of MTime and URI by @chrysn in #230
  * Prefer x11 over Wayland GDK backend (it overall provides a better experience)
  * Fix Client Side Decorations (CSD), e.g. in Wayland
  * Fix race/crash upon exit (Fixes #227)
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 2.12:
  * Fix external image filters (Fixes #182)
  * Fix support for best interpolation quality (Fixes #139)
  * Fix wrap-around in shuffled image view (Fixes #176)
  * Fix max-depth behavior if the argument is a file (Fixes #170)
  * Allow keybinding of special keys with shift modifier
  * Add --auto-montage-mode (Fixes #181)
  * Replace GTimeVal with GDateTime for glib 2.62 support
  * Add an sxiv-like marks system
* Fri Aug 14 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.11
